import os

VERSION = "UNKNOWN"

try:
    PATH = os.path.abspath(os.path.dirname(__file__))
    VERSION_FILE = os.path.join(PATH, "version.txt")
    with open(VERSION_FILE) as ifp:
        VERSION = ifp.read().strip()
except:
    pass



"""seer raw index

Revision ID: 090c247f8618
Revises: 2e90b758090c
Create Date: 2024-07-24 14:55:15.986453

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = "090c247f8618"
down_revision: Union[str, None] = "2e90b758090c"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index(
        "uk_amoy_labels_tx_hash_log_idx_evt_raw",
        "amoy_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_amoy_labels_tx_hash_tx_call_raw",
        "amoy_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_arbitrum_nova_labels_tx_hash_log_idx_evt_raw",
        "arbitrum_nova_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_arbitrum_nova_labels_tx_hash_tx_call_raw",
        "arbitrum_nova_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_arbitrum_one_labels_tx_hash_log_idx_evt_raw",
        "arbitrum_one_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_arbitrum_one_labels_tx_hash_tx_call_raw",
        "arbitrum_one_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw",
        "arbitrum_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_arbitrum_sepolia_labels_tx_hash_tx_call_raw",
        "arbitrum_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_avalanche_fuji_labels_tx_hash_log_idx_evt_raw",
        "avalanche_fuji_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_avalanche_fuji_labels_tx_hash_tx_call_raw",
        "avalanche_fuji_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_avalanche_labels_tx_hash_log_idx_evt_raw",
        "avalanche_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_avalanche_labels_tx_hash_tx_call_raw",
        "avalanche_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_base_labels_tx_hash_log_idx_evt_raw",
        "base_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_base_labels_tx_hash_tx_call_raw",
        "base_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_blast_labels_tx_hash_log_idx_evt_raw",
        "blast_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_blast_labels_tx_hash_tx_call_raw",
        "blast_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_blast_sepolia_labels_tx_hash_log_idx_evt_raw",
        "blast_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_blast_sepolia_labels_tx_hash_tx_call_raw",
        "blast_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_ethereum_labels_tx_hash_log_idx_evt_raw",
        "ethereum_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_ethereum_labels_tx_hash_tx_call_raw",
        "ethereum_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw",
        "game7_orbit_arbitrum_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call_raw",
        "game7_orbit_arbitrum_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_mantle_labels_tx_hash_log_idx_evt_raw",
        "mantle_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_mantle_labels_tx_hash_tx_call_raw",
        "mantle_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_mantle_sepolia_labels_tx_hash_log_idx_evt_raw",
        "mantle_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_mantle_sepolia_labels_tx_hash_tx_call_raw",
        "mantle_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_mumbai_labels_tx_hash_log_idx_evt_raw",
        "mumbai_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_mumbai_labels_tx_hash_tx_call_raw",
        "mumbai_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_polygon_labels_tx_hash_log_idx_evt_raw",
        "polygon_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_polygon_labels_tx_hash_tx_call_raw",
        "polygon_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_proofofplay_apex_labels_tx_hash_log_idx_evt_raw",
        "proofofplay_apex_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_proofofplay_apex_labels_tx_hash_tx_call_raw",
        "proofofplay_apex_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_sepolia_labels_tx_hash_log_idx_evt_raw",
        "sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_sepolia_labels_tx_hash_tx_call_raw",
        "sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_starknet_labels_tx_hash_log_idx_evt_raw",
        "starknet_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_starknet_labels_tx_hash_tx_call_raw",
        "starknet_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_starknet_sepolia_labels_tx_hash_log_idx_evt_raw",
        "starknet_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_starknet_sepolia_labels_tx_hash_tx_call_raw",
        "starknet_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_xai_labels_tx_hash_log_idx_evt_raw",
        "xai_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_xai_labels_tx_hash_tx_call_raw",
        "xai_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_xai_sepolia_labels_tx_hash_log_idx_evt_raw",
        "xai_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_xai_sepolia_labels_tx_hash_tx_call_raw",
        "xai_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_xdai_labels_tx_hash_log_idx_evt_raw",
        "xdai_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_xdai_labels_tx_hash_tx_call_raw",
        "xdai_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_zksync_era_labels_tx_hash_log_idx_evt_raw",
        "zksync_era_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_zksync_era_labels_tx_hash_tx_call_raw",
        "zksync_era_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.create_index(
        "uk_zksync_era_sepolia_labels_tx_hash_log_idx_evt_raw",
        "zksync_era_sepolia_labels",
        ["transaction_hash", "log_index"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.create_index(
        "uk_zksync_era_sepolia_labels_tx_hash_tx_call_raw",
        "zksync_era_sepolia_labels",
        ["transaction_hash"],
        unique=True,
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        "uk_zksync_era_sepolia_labels_tx_hash_tx_call_raw",
        table_name="zksync_era_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_zksync_era_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="zksync_era_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_zksync_era_labels_tx_hash_tx_call_raw",
        table_name="zksync_era_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_zksync_era_labels_tx_hash_log_idx_evt_raw",
        table_name="zksync_era_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_xdai_labels_tx_hash_tx_call_raw",
        table_name="xdai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_xdai_labels_tx_hash_log_idx_evt_raw",
        table_name="xdai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_xai_sepolia_labels_tx_hash_tx_call_raw",
        table_name="xai_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_xai_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="xai_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_xai_labels_tx_hash_tx_call_raw",
        table_name="xai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_xai_labels_tx_hash_log_idx_evt_raw",
        table_name="xai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_starknet_sepolia_labels_tx_hash_tx_call_raw",
        table_name="starknet_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_starknet_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="starknet_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_starknet_labels_tx_hash_tx_call_raw",
        table_name="starknet_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_starknet_labels_tx_hash_log_idx_evt_raw",
        table_name="starknet_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_sepolia_labels_tx_hash_tx_call_raw",
        table_name="sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_proofofplay_apex_labels_tx_hash_tx_call_raw",
        table_name="proofofplay_apex_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_proofofplay_apex_labels_tx_hash_log_idx_evt_raw",
        table_name="proofofplay_apex_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_polygon_labels_tx_hash_tx_call_raw",
        table_name="polygon_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_polygon_labels_tx_hash_log_idx_evt_raw",
        table_name="polygon_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_mumbai_labels_tx_hash_tx_call_raw",
        table_name="mumbai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_mumbai_labels_tx_hash_log_idx_evt_raw",
        table_name="mumbai_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_mantle_sepolia_labels_tx_hash_tx_call_raw",
        table_name="mantle_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_mantle_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="mantle_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_mantle_labels_tx_hash_tx_call_raw",
        table_name="mantle_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_mantle_labels_tx_hash_log_idx_evt_raw",
        table_name="mantle_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_g7o_arbitrum_sepolia_labels_tx_hash_tx_call_raw",
        table_name="game7_orbit_arbitrum_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_g7o_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="game7_orbit_arbitrum_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_ethereum_labels_tx_hash_tx_call_raw",
        table_name="ethereum_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_ethereum_labels_tx_hash_log_idx_evt_raw",
        table_name="ethereum_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_blast_sepolia_labels_tx_hash_tx_call_raw",
        table_name="blast_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_blast_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="blast_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_blast_labels_tx_hash_tx_call_raw",
        table_name="blast_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_blast_labels_tx_hash_log_idx_evt_raw",
        table_name="blast_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_base_labels_tx_hash_tx_call_raw",
        table_name="base_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_base_labels_tx_hash_log_idx_evt_raw",
        table_name="base_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_avalanche_labels_tx_hash_tx_call_raw",
        table_name="avalanche_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_avalanche_labels_tx_hash_log_idx_evt_raw",
        table_name="avalanche_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_avalanche_fuji_labels_tx_hash_tx_call_raw",
        table_name="avalanche_fuji_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_avalanche_fuji_labels_tx_hash_log_idx_evt_raw",
        table_name="avalanche_fuji_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_arbitrum_sepolia_labels_tx_hash_tx_call_raw",
        table_name="arbitrum_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_arbitrum_sepolia_labels_tx_hash_log_idx_evt_raw",
        table_name="arbitrum_sepolia_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_arbitrum_one_labels_tx_hash_tx_call_raw",
        table_name="arbitrum_one_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_arbitrum_one_labels_tx_hash_log_idx_evt_raw",
        table_name="arbitrum_one_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_arbitrum_nova_labels_tx_hash_tx_call_raw",
        table_name="arbitrum_nova_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_arbitrum_nova_labels_tx_hash_log_idx_evt_raw",
        table_name="arbitrum_nova_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    op.drop_index(
        "uk_amoy_labels_tx_hash_tx_call_raw",
        table_name="amoy_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='tx_call'"),
    )
    op.drop_index(
        "uk_amoy_labels_tx_hash_log_idx_evt_raw",
        table_name="amoy_labels",
        postgresql_where=sa.text("label='seer-raw' and label_type='event'"),
    )
    # ### end Alembic commands ###



"""tx call and event unique indexes

Revision ID: d2ceff33be47
Revises: e9f640a2b45b
Create Date: 2024-05-17 16:35:56.059519

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'd2ceff33be47'
down_revision: Union[str, None] = 'e9f640a2b45b'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    # uq_amoy_labels
    op.create_index('uk_amoy_labels_tx_hash_log_idx_evt', 'amoy_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_amoy_labels_tx_hash_tx_call', 'amoy_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_arbitrum_nova_labels
    op.create_index('uk_arbitrum_nova_labels_tx_hash_log_idx_evt', 'arbitrum_nova_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_arbitrum_nova_labels_tx_hash_tx_call', 'arbitrum_nova_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_arbitrum_one_labels
    op.create_index('uk_arbitrum_one_labels_tx_hash_log_idx_evt', 'arbitrum_one_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_arbitrum_one_labels_tx_hash_tx_call', 'arbitrum_one_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_arbitrum_sepolia_labels
    op.create_index('uk_arbitrum_sepolia_labels_tx_hash_log_idx_evt', 'arbitrum_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_arbitrum_sepolia_labels_tx_hash_tx_call', 'arbitrum_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_avalanche_fuji_labels
    op.create_index('uk_avalanche_fuji_labels_tx_hash_log_idx_evt', 'avalanche_fuji_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_avalanche_fuji_labels_tx_hash_tx_call', 'avalanche_fuji_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_avalanche_labels
    op.create_index('uk_avalanche_labels_tx_hash_log_idx_evt', 'avalanche_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_avalanche_labels_tx_hash_tx_call', 'avalanche_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_base_labels
    op.create_index('uk_base_labels_tx_hash_log_idx_evt', 'base_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_base_labels_tx_hash_tx_call', 'base_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_blast_labels
    op.create_index('uk_blast_labels_tx_hash_log_idx_evt', 'blast_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_blast_labels_tx_hash_tx_call', 'blast_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_blast_sepolia_labels
    op.create_index('uk_blast_sepolia_labels_tx_hash_log_idx_evt', 'blast_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_blast_sepolia_labels_tx_hash_tx_call', 'blast_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_ethereum_labels
    op.create_index('uk_ethereum_labels_tx_hash_log_idx_evt', 'ethereum_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_ethereum_labels_tx_hash_tx_call', 'ethereum_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_mumbai_labels
    op.create_index('uk_mumbai_labels_tx_hash_log_idx_evt', 'mumbai_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_mumbai_labels_tx_hash_tx_call', 'mumbai_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_polygon_labels
    op.create_index('uk_polygon_labels_tx_hash_log_idx_evt', 'polygon_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_polygon_labels_tx_hash_tx_call', 'polygon_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_proofofplay_apex_labels
    op.create_index('uk_proofofplay_apex_labels_tx_hash_log_idx_evt', 'proofofplay_apex_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_proofofplay_apex_labels_tx_hash_tx_call', 'proofofplay_apex_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_sepolia_labels
    op.create_index('uk_sepolia_labels_tx_hash_log_idx_evt', 'sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_sepolia_labels_tx_hash_tx_call', 'sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_starknet_labels
    op.create_index('uk_starknet_labels_tx_hash_log_idx_evt', 'starknet_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_starknet_labels_tx_hash_tx_call', 'starknet_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_starknet_sepolia_labels
    op.create_index('uk_starknet_sepolia_labels_tx_hash_log_idx_evt', 'starknet_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_starknet_sepolia_labels_tx_hash_tx_call', 'starknet_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_xai_labels
    op.create_index('uk_xai_labels_tx_hash_log_idx_evt', 'xai_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_xai_labels_tx_hash_tx_call', 'xai_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # uq_xai_sepolia_labels
    op.create_index('uk_xai_sepolia_labels_tx_hash_log_idx_evt', 'xai_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_xai_sepolia_labels_tx_hash_tx_call', 'xai_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # xdai_labels
    op.create_index('uk_xdai_labels_tx_hash_log_idx_evt', 'xdai_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_xdai_labels_tx_hash_tx_call', 'xdai_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # zksync_era_labels
    op.create_index('uk_zksync_era_labels_tx_hash_log_idx_evt', 'zksync_era_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_zksync_era_labels_tx_hash_tx_call', 'zksync_era_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # zksync_era_sepolia_labels
    op.create_index('uk_zksync_era_sepolia_labels_tx_hash_log_idx_evt', 'zksync_era_sepolia_labels', ['transaction_hash', 'log_index'], unique=True, postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.create_index('uk_zksync_era_sepolia_labels_tx_hash_tx_call', 'zksync_era_sepolia_labels', ['transaction_hash'], unique=True, postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('uk_zksync_era_sepolia_labels_tx_hash_tx_call', table_name='zksync_era_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_zksync_era_sepolia_labels_tx_hash_log_idx_evt', table_name='zksync_era_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_zksync_era_labels_tx_hash_tx_call', table_name='zksync_era_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_zksync_era_labels_tx_hash_log_idx_evt', table_name='zksync_era_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_xdai_labels_tx_hash_tx_call', table_name='xdai_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_xdai_labels_tx_hash_log_idx_evt', table_name='xdai_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_xai_sepolia_labels_tx_hash_tx_call', table_name='xai_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_xai_sepolia_labels_tx_hash_log_idx_evt', table_name='xai_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_xai_labels_tx_hash_tx_call', table_name='xai_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_xai_labels_tx_hash_log_idx_evt', table_name='xai_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_starknet_sepolia_labels_tx_hash_tx_call', table_name='starknet_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_starknet_sepolia_labels_tx_hash_log_idx_evt', table_name='starknet_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_starknet_labels_tx_hash_tx_call', table_name='starknet_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_starknet_labels_tx_hash_log_idx_evt', table_name='starknet_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_sepolia_labels_tx_hash_tx_call', table_name='sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_sepolia_labels_tx_hash_log_idx_evt', table_name='sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_proofofplay_apex_labels_tx_hash_tx_call', table_name='proofofplay_apex_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_proofofplay_apex_labels_tx_hash_log_idx_evt', table_name='proofofplay_apex_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_polygon_labels_tx_hash_tx_call', table_name='polygon_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_polygon_labels_tx_hash_log_idx_evt', table_name='polygon_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_mumbai_labels_tx_hash_tx_call', table_name='mumbai_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_mumbai_labels_tx_hash_log_idx_evt', table_name='mumbai_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_ethereum_labels_tx_hash_tx_call', table_name='ethereum_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_ethereum_labels_tx_hash_log_idx_evt', table_name='ethereum_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_blast_sepolia_labels_tx_hash_tx_call', table_name='blast_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_blast_sepolia_labels_tx_hash_log_idx_evt', table_name='blast_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_blast_labels_tx_hash_tx_call', table_name='blast_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_blast_labels_tx_hash_log_idx_evt', table_name='blast_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_base_labels_tx_hash_tx_call', table_name='base_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_base_labels_tx_hash_log_idx_evt', table_name='base_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_avalanche_labels_tx_hash_tx_call', table_name='avalanche_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_avalanche_labels_tx_hash_log_idx_evt', table_name='avalanche_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_avalanche_fuji_labels_tx_hash_tx_call', table_name='avalanche_fuji_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_avalanche_fuji_labels_tx_hash_log_idx_evt', table_name='avalanche_fuji_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_arbitrum_sepolia_labels_tx_hash_tx_call', table_name='arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_arbitrum_sepolia_labels_tx_hash_log_idx_evt', table_name='arbitrum_sepolia_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_arbitrum_one_labels_tx_hash_tx_call', table_name='arbitrum_one_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_arbitrum_one_labels_tx_hash_log_idx_evt', table_name='arbitrum_one_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_arbitrum_nova_labels_tx_hash_tx_call', table_name='arbitrum_nova_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_arbitrum_nova_labels_tx_hash_log_idx_evt', table_name='arbitrum_nova_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    op.drop_index('uk_amoy_labels_tx_hash_tx_call', table_name='amoy_labels', postgresql_where=sa.text("label='seer' and label_type='tx_call'"))
    op.drop_index('uk_amoy_labels_tx_hash_log_idx_evt', table_name='amoy_labels', postgresql_where=sa.text("label='seer' and label_type='event'"))
    # ### end Alembic commands ###



"""Add v3 subscription

Revision ID: f2c6aa92e5d2
Revises: 27086791044c
Create Date: 2024-07-11 19:41:49.899157

"""

from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = "f2c6aa92e5d2"
down_revision: Union[str, None] = "27086791044c"
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        "abi_subscriptions",
        sa.Column("abi_job_id", sa.UUID(), nullable=False),
        sa.Column("subscription_id", sa.UUID(), nullable=False),
        sa.Column(
            "created_at",
            sa.DateTime(timezone=True),
            server_default=sa.text("TIMEZONE('utc', statement_timestamp())"),
            nullable=False,
        ),
        sa.ForeignKeyConstraint(
            ["abi_job_id"],
            ["abi_jobs.id"],
            name=op.f("fk_abi_subscriptions_abi_job_id_abi_jobs"),
        ),
        sa.PrimaryKeyConstraint(
            "abi_job_id", "subscription_id", name=op.f("pk_abi_subscriptions")
        ),
    )
    op.create_index(
        op.f("ix_abi_subscriptions_abi_job_id"),
        "abi_subscriptions",
        ["abi_job_id"],
        unique=False,
    )
    op.create_index(
        op.f("ix_abi_subscriptions_subscription_id"),
        "abi_subscriptions",
        ["subscription_id"],
        unique=False,
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(
        op.f("ix_abi_subscriptions_subscription_id"), table_name="abi_subscriptions"
    )
    op.drop_index(
        op.f("ix_abi_subscriptions_abi_job_id"), table_name="abi_subscriptions"
    )
    op.drop_table("abi_subscriptions")
    # ### end Alembic commands ###



"""Amoy, Blast and Apex blockchains

Revision ID: e9e1b43f49e1
Revises: 994e614b5500
Create Date: 2024-04-22 09:35:56.509834

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = 'e9e1b43f49e1'
down_revision: Union[str, None] = '994e614b5500'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('amoy_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_amoy_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_amoy_labels_id'))
    )
    op.create_index('ix_amoy_labels_addr_block_num', 'amoy_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_amoy_labels_addr_block_ts', 'amoy_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_amoy_labels_address'), 'amoy_labels', ['address'], unique=False)
    op.create_index(op.f('ix_amoy_labels_block_number'), 'amoy_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_amoy_labels_caller_address'), 'amoy_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_amoy_labels_label'), 'amoy_labels', ['label'], unique=False)
    op.create_index(op.f('ix_amoy_labels_label_name'), 'amoy_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_amoy_labels_label_type'), 'amoy_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_amoy_labels_origin_address'), 'amoy_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_amoy_labels_transaction_hash'), 'amoy_labels', ['transaction_hash'], unique=False)
    op.create_table('blast_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_blast_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_blast_labels_id'))
    )
    op.create_index('ix_blast_labels_addr_block_num', 'blast_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_blast_labels_addr_block_ts', 'blast_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_blast_labels_address'), 'blast_labels', ['address'], unique=False)
    op.create_index(op.f('ix_blast_labels_block_number'), 'blast_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_blast_labels_caller_address'), 'blast_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_blast_labels_label'), 'blast_labels', ['label'], unique=False)
    op.create_index(op.f('ix_blast_labels_label_name'), 'blast_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_blast_labels_label_type'), 'blast_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_blast_labels_origin_address'), 'blast_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_blast_labels_transaction_hash'), 'blast_labels', ['transaction_hash'], unique=False)
    op.create_table('blast_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_blast_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_blast_sepolia_labels_id'))
    )
    op.create_index('ix_blast_sepolia_labels_addr_block_num', 'blast_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_blast_sepolia_labels_addr_block_ts', 'blast_sepolia_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_address'), 'blast_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_block_number'), 'blast_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_caller_address'), 'blast_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_label'), 'blast_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_label_name'), 'blast_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_label_type'), 'blast_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_origin_address'), 'blast_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_blast_sepolia_labels_transaction_hash'), 'blast_sepolia_labels', ['transaction_hash'], unique=False)
    op.create_table('proofofplay_apex_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_proofofplay_apex_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_proofofplay_apex_labels_id'))
    )
    op.create_index('ix_proofofplay_apex_labels_addr_block_num', 'proofofplay_apex_labels', ['address', 'block_number'], unique=False)
    op.create_index('ix_proofofplay_apex_labels_addr_block_ts', 'proofofplay_apex_labels', ['address', 'block_timestamp'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_address'), 'proofofplay_apex_labels', ['address'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_block_number'), 'proofofplay_apex_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_caller_address'), 'proofofplay_apex_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_label'), 'proofofplay_apex_labels', ['label'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_label_name'), 'proofofplay_apex_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_label_type'), 'proofofplay_apex_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_origin_address'), 'proofofplay_apex_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_proofofplay_apex_labels_transaction_hash'), 'proofofplay_apex_labels', ['transaction_hash'], unique=False)
    op.create_index('ix_arbitrum_nova_labels_addr_block_ts', 'arbitrum_nova_labels', ['address', 'block_timestamp'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###    
    op.drop_index(op.f('ix_proofofplay_apex_labels_transaction_hash'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_origin_address'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_label_type'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_label_name'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_label'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_caller_address'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_block_number'), table_name='proofofplay_apex_labels')
    op.drop_index(op.f('ix_proofofplay_apex_labels_address'), table_name='proofofplay_apex_labels')
    op.drop_index('ix_proofofplay_apex_labels_addr_block_ts', table_name='proofofplay_apex_labels')
    op.drop_index('ix_proofofplay_apex_labels_addr_block_num', table_name='proofofplay_apex_labels')
    op.drop_table('proofofplay_apex_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_transaction_hash'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_origin_address'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_label_type'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_label_name'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_label'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_caller_address'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_block_number'), table_name='blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_sepolia_labels_address'), table_name='blast_sepolia_labels')
    op.drop_index('ix_blast_sepolia_labels_addr_block_ts', table_name='blast_sepolia_labels')
    op.drop_index('ix_blast_sepolia_labels_addr_block_num', table_name='blast_sepolia_labels')
    op.drop_table('blast_sepolia_labels')
    op.drop_index(op.f('ix_blast_labels_transaction_hash'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_origin_address'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_label_type'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_label_name'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_label'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_caller_address'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_block_number'), table_name='blast_labels')
    op.drop_index(op.f('ix_blast_labels_address'), table_name='blast_labels')
    op.drop_index('ix_blast_labels_addr_block_ts', table_name='blast_labels')
    op.drop_index('ix_blast_labels_addr_block_num', table_name='blast_labels')
    op.drop_table('blast_labels')
    op.drop_index(op.f('ix_amoy_labels_transaction_hash'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_origin_address'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_label_type'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_label_name'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_label'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_caller_address'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_block_number'), table_name='amoy_labels')
    op.drop_index(op.f('ix_amoy_labels_address'), table_name='amoy_labels')
    op.drop_index('ix_amoy_labels_addr_block_ts', table_name='amoy_labels')
    op.drop_index('ix_amoy_labels_addr_block_num', table_name='amoy_labels')
    op.drop_table('amoy_labels')
    # ### end Alembic commands ###



"""Tables initial generation

Revision ID: 994e614b5500
Revises: 
Create Date: 2024-03-14 07:03:35.586195

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa
from sqlalchemy.dialects import postgresql

# revision identifiers, used by Alembic.
revision: str = '994e614b5500'
down_revision: Union[str, None] = None
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('arbitrum_nova_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_arbitrum_nova_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_arbitrum_nova_labels_id')),
    )
    op.create_index('ix_arbitrum_nova_labels_addr_block_num', 'arbitrum_nova_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_address'), 'arbitrum_nova_labels', ['address'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_block_number'), 'arbitrum_nova_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_caller_address'), 'arbitrum_nova_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_label'), 'arbitrum_nova_labels', ['label'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_label_name'), 'arbitrum_nova_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_label_type'), 'arbitrum_nova_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_origin_address'), 'arbitrum_nova_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_arbitrum_nova_labels_transaction_hash'), 'arbitrum_nova_labels', ['transaction_hash'], unique=False)
    op.create_table('arbitrum_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_arbitrum_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_arbitrum_sepolia_labels_id'))
    )
    op.create_index('ix_arbitrum_sepolia_labels_addr_block_num', 'arbitrum_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_address'), 'arbitrum_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_block_number'), 'arbitrum_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_caller_address'), 'arbitrum_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_label'), 'arbitrum_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_label_name'), 'arbitrum_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_label_type'), 'arbitrum_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_origin_address'), 'arbitrum_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_arbitrum_sepolia_labels_transaction_hash'), 'arbitrum_sepolia_labels', ['transaction_hash'], unique=False)
    op.create_table('base_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_base_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_base_labels_id'))
    )
    op.create_index('ix_base_labels_addr_block_num', 'base_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_base_labels_address'), 'base_labels', ['address'], unique=False)
    op.create_index(op.f('ix_base_labels_block_number'), 'base_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_base_labels_caller_address'), 'base_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_base_labels_label'), 'base_labels', ['label'], unique=False)
    op.create_index(op.f('ix_base_labels_label_name'), 'base_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_base_labels_label_type'), 'base_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_base_labels_origin_address'), 'base_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_base_labels_transaction_hash'), 'base_labels', ['transaction_hash'], unique=False)
    op.create_table('ethereum_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_ethereum_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_ethereum_labels_id'))
    )
    op.create_index('ix_ethereum_labels_addr_block_num', 'ethereum_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_address'), 'ethereum_labels', ['address'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_block_number'), 'ethereum_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_caller_address'), 'ethereum_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_label'), 'ethereum_labels', ['label'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_label_name'), 'ethereum_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_label_type'), 'ethereum_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_origin_address'), 'ethereum_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_ethereum_labels_transaction_hash'), 'ethereum_labels', ['transaction_hash'], unique=False)
    op.create_table('mumbai_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_mumbai_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_mumbai_labels_id'))
    )
    op.create_index('ix_mumbai_labels_addr_block_num', 'mumbai_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_address'), 'mumbai_labels', ['address'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_block_number'), 'mumbai_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_caller_address'), 'mumbai_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_label'), 'mumbai_labels', ['label'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_label_name'), 'mumbai_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_label_type'), 'mumbai_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_origin_address'), 'mumbai_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_mumbai_labels_transaction_hash'), 'mumbai_labels', ['transaction_hash'], unique=False)
    op.create_table('polygon_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_polygon_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_polygon_labels_id'))
    )
    op.create_index('ix_polygon_labels_addr_block_num', 'polygon_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_polygon_labels_address'), 'polygon_labels', ['address'], unique=False)
    op.create_index(op.f('ix_polygon_labels_block_number'), 'polygon_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_polygon_labels_caller_address'), 'polygon_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_polygon_labels_label'), 'polygon_labels', ['label'], unique=False)
    op.create_index(op.f('ix_polygon_labels_label_name'), 'polygon_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_polygon_labels_label_type'), 'polygon_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_polygon_labels_origin_address'), 'polygon_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_polygon_labels_transaction_hash'), 'polygon_labels', ['transaction_hash'], unique=False)
    op.create_table('sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_sepolia_labels_id'))
    )
    op.create_index('ix_sepolia_labels_addr_block_num', 'sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_address'), 'sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_block_number'), 'sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_caller_address'), 'sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_label'), 'sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_label_name'), 'sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_label_type'), 'sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_origin_address'), 'sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_sepolia_labels_transaction_hash'), 'sepolia_labels', ['transaction_hash'], unique=False)
    op.create_table('xai_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_xai_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_xai_labels_id'))
    )
    op.create_index('ix_xai_labels_addr_block_num', 'xai_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_xai_labels_address'), 'xai_labels', ['address'], unique=False)
    op.create_index(op.f('ix_xai_labels_block_number'), 'xai_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_xai_labels_caller_address'), 'xai_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_xai_labels_label'), 'xai_labels', ['label'], unique=False)
    op.create_index(op.f('ix_xai_labels_label_name'), 'xai_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_xai_labels_label_type'), 'xai_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_xai_labels_origin_address'), 'xai_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_xai_labels_transaction_hash'), 'xai_labels', ['transaction_hash'], unique=False)
    op.create_table('xai_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_xai_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_xai_sepolia_labels_id'))
    )
    op.create_index('ix_xai_sepolia_labels_addr_block_num', 'xai_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_address'), 'xai_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_block_number'), 'xai_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_caller_address'), 'xai_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_label'), 'xai_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_label_name'), 'xai_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_label_type'), 'xai_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_origin_address'), 'xai_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_xai_sepolia_labels_transaction_hash'), 'xai_sepolia_labels', ['transaction_hash'], unique=False)
    op.create_table('xdai_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_xdai_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_xdai_labels_id'))
    )
    op.create_index('ix_xdai_labels_addr_block_num', 'xdai_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_xdai_labels_address'), 'xdai_labels', ['address'], unique=False)
    op.create_index(op.f('ix_xdai_labels_block_number'), 'xdai_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_xdai_labels_caller_address'), 'xdai_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_xdai_labels_label'), 'xdai_labels', ['label'], unique=False)
    op.create_index(op.f('ix_xdai_labels_label_name'), 'xdai_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_xdai_labels_label_type'), 'xdai_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_xdai_labels_origin_address'), 'xdai_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_xdai_labels_transaction_hash'), 'xdai_labels', ['transaction_hash'], unique=False)
    op.create_table('zksync_era_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_zksync_era_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_zksync_era_labels_id'))
    )
    op.create_index('ix_zksync_era_labels_addr_block_num', 'zksync_era_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_address'), 'zksync_era_labels', ['address'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_block_number'), 'zksync_era_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_caller_address'), 'zksync_era_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_label'), 'zksync_era_labels', ['label'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_label_name'), 'zksync_era_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_label_type'), 'zksync_era_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_origin_address'), 'zksync_era_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_zksync_era_labels_transaction_hash'), 'zksync_era_labels', ['transaction_hash'], unique=False)
    op.create_table('zksync_era_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_zksync_era_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_zksync_era_sepolia_labels_id'))
    )
    op.create_index('ix_zksync_era_sepolia_labels_addr_block_num', 'zksync_era_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_address'), 'zksync_era_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_block_number'), 'zksync_era_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_caller_address'), 'zksync_era_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_label'), 'zksync_era_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_label_name'), 'zksync_era_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_label_type'), 'zksync_era_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_origin_address'), 'zksync_era_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_zksync_era_sepolia_labels_transaction_hash'), 'zksync_era_sepolia_labels', ['transaction_hash'], unique=False)
    op.create_table('avalanche_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_avalanche_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_avalanche_labels_id'))
    )
    op.create_index('ix_avalanche_labels_addr_block_num', 'avalanche_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_address'), 'avalanche_labels', ['address'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_block_number'), 'avalanche_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_caller_address'), 'avalanche_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_label'), 'avalanche_labels', ['label'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_label_name'), 'avalanche_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_label_type'), 'avalanche_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_origin_address'), 'avalanche_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_avalanche_labels_transaction_hash'), 'avalanche_labels', ['transaction_hash'], unique=False)
    op.create_table('avalanche_fuji_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_avalanche_fuji_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_avalanche_fuji_labels_id'))
    )
    op.create_index('ix_avalanche_fuji_labels_addr_block_num', 'avalanche_fuji_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_address'), 'avalanche_fuji_labels', ['address'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_block_number'), 'avalanche_fuji_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_caller_address'), 'avalanche_fuji_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_label'), 'avalanche_fuji_labels', ['label'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_label_name'), 'avalanche_fuji_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_label_type'), 'avalanche_fuji_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_origin_address'), 'avalanche_fuji_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_avalanche_fuji_labels_transaction_hash'), 'avalanche_fuji_labels', ['transaction_hash'], unique=False)
    op.create_table('starknet_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_starknet_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_starknet_labels_id'))
    )
    op.create_index('ix_starknet_labels_addr_block_num', 'starknet_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_starknet_labels_address'), 'starknet_labels', ['address'], unique=False)
    op.create_index(op.f('ix_starknet_labels_block_number'), 'starknet_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_starknet_labels_caller_address'), 'starknet_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_starknet_labels_label'), 'starknet_labels', ['label'], unique=False)
    op.create_index(op.f('ix_starknet_labels_label_name'), 'starknet_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_starknet_labels_label_type'), 'starknet_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_starknet_labels_origin_address'), 'starknet_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_starknet_labels_transaction_hash'), 'starknet_labels', ['transaction_hash'], unique=False)
    op.create_table('starknet_sepolia_labels',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('label', sa.VARCHAR(length=256), nullable=False),
    sa.Column('transaction_hash', sa.VARCHAR(length=128), nullable=False),
    sa.Column('log_index', sa.Integer(), nullable=True),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('caller_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('origin_address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('address', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_name', sa.Text(), nullable=True),
    sa.Column('label_type', sa.VARCHAR(length=64), nullable=True),
    sa.Column('label_data', postgresql.JSONB(astext_type=sa.Text()), nullable=True),
    sa.Column('created_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_starknet_sepolia_labels')),
    sa.UniqueConstraint('id', name=op.f('uq_starknet_sepolia_labels_id'))
    )
    op.create_index('ix_starknet_sepolia_labels_addr_block_num', 'starknet_sepolia_labels', ['address', 'block_number'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_address'), 'starknet_sepolia_labels', ['address'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_block_number'), 'starknet_sepolia_labels', ['block_number'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_caller_address'), 'starknet_sepolia_labels', ['caller_address'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_label'), 'starknet_sepolia_labels', ['label'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_label_name'), 'starknet_sepolia_labels', ['label_name'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_label_type'), 'starknet_sepolia_labels', ['label_type'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_origin_address'), 'starknet_sepolia_labels', ['origin_address'], unique=False)
    op.create_index(op.f('ix_starknet_sepolia_labels_transaction_hash'), 'starknet_sepolia_labels', ['transaction_hash'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_transaction_hash'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_origin_address'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_label_type'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_label_name'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_label'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_caller_address'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_block_number'), table_name='zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_sepolia_labels_address'), table_name='zksync_era_sepolia_labels')
    op.drop_index('ix_zksync_era_sepolia_labels_addr_block_num', table_name='zksync_era_sepolia_labels')
    op.drop_table('zksync_era_sepolia_labels')
    op.drop_index(op.f('ix_zksync_era_labels_transaction_hash'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_origin_address'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_label_type'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_label_name'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_label'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_caller_address'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_block_number'), table_name='zksync_era_labels')
    op.drop_index(op.f('ix_zksync_era_labels_address'), table_name='zksync_era_labels')
    op.drop_index('ix_zksync_era_labels_addr_block_num', table_name='zksync_era_labels')
    op.drop_table('zksync_era_labels')
    op.drop_index(op.f('ix_xdai_labels_transaction_hash'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_origin_address'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_label_type'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_label_name'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_label'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_caller_address'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_block_number'), table_name='xdai_labels')
    op.drop_index(op.f('ix_xdai_labels_address'), table_name='xdai_labels')
    op.drop_index('ix_xdai_labels_addr_block_num', table_name='xdai_labels')
    op.drop_table('xdai_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_transaction_hash'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_origin_address'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_label_type'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_label_name'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_label'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_caller_address'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_block_number'), table_name='xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_sepolia_labels_address'), table_name='xai_sepolia_labels')
    op.drop_index('ix_xai_sepolia_labels_addr_block_num', table_name='xai_sepolia_labels')
    op.drop_table('xai_sepolia_labels')
    op.drop_index(op.f('ix_xai_labels_transaction_hash'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_origin_address'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_label_type'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_label_name'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_label'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_caller_address'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_block_number'), table_name='xai_labels')
    op.drop_index(op.f('ix_xai_labels_address'), table_name='xai_labels')
    op.drop_index('ix_xai_labels_addr_block_num', table_name='xai_labels')
    op.drop_table('xai_labels')
    op.drop_index(op.f('ix_sepolia_labels_transaction_hash'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_origin_address'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_label_type'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_label_name'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_label'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_caller_address'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_block_number'), table_name='sepolia_labels')
    op.drop_index(op.f('ix_sepolia_labels_address'), table_name='sepolia_labels')
    op.drop_index('ix_sepolia_labels_addr_block_num', table_name='sepolia_labels')
    op.drop_table('sepolia_labels')
    op.drop_index(op.f('ix_polygon_labels_transaction_hash'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_origin_address'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_label_type'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_label_name'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_label'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_caller_address'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_block_number'), table_name='polygon_labels')
    op.drop_index(op.f('ix_polygon_labels_address'), table_name='polygon_labels')
    op.drop_index('ix_polygon_labels_addr_block_num', table_name='polygon_labels')
    op.drop_table('polygon_labels')
    op.drop_index(op.f('ix_mumbai_labels_transaction_hash'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_origin_address'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_label_type'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_label_name'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_label'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_caller_address'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_block_number'), table_name='mumbai_labels')
    op.drop_index(op.f('ix_mumbai_labels_address'), table_name='mumbai_labels')
    op.drop_index('ix_mumbai_labels_addr_block_num', table_name='mumbai_labels')
    op.drop_table('mumbai_labels')
    op.drop_index(op.f('ix_ethereum_labels_transaction_hash'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_origin_address'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_label_type'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_label_name'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_label'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_caller_address'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_block_number'), table_name='ethereum_labels')
    op.drop_index(op.f('ix_ethereum_labels_address'), table_name='ethereum_labels')
    op.drop_index('ix_ethereum_labels_addr_block_num', table_name='ethereum_labels')
    op.drop_table('ethereum_labels')
    op.drop_index(op.f('ix_base_labels_transaction_hash'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_origin_address'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_label_type'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_label_name'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_label'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_caller_address'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_block_number'), table_name='base_labels')
    op.drop_index(op.f('ix_base_labels_address'), table_name='base_labels')
    op.drop_index('ix_base_labels_addr_block_num', table_name='base_labels')
    op.drop_table('base_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_transaction_hash'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_origin_address'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_label_type'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_label_name'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_label'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_caller_address'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_block_number'), table_name='arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_sepolia_labels_address'), table_name='arbitrum_sepolia_labels')
    op.drop_index('ix_arbitrum_sepolia_labels_addr_block_num', table_name='arbitrum_sepolia_labels')
    op.drop_table('arbitrum_sepolia_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_transaction_hash'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_origin_address'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_label_type'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_label_name'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_label'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_caller_address'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_block_number'), table_name='arbitrum_nova_labels')
    op.drop_index(op.f('ix_arbitrum_nova_labels_address'), table_name='arbitrum_nova_labels')
    op.drop_index('ix_arbitrum_nova_labels_addr_block_num', table_name='arbitrum_nova_labels')
    op.drop_table('arbitrum_nova_labels')
    op.drop_index(op.f('ix_avalanche_labels_transaction_hash'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_origin_address'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_label_type'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_label_name'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_label'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_caller_address'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_block_number'), table_name='avalanche_labels')
    op.drop_index(op.f('ix_avalanche_labels_address'), table_name='avalanche_labels')
    op.drop_index('ix_avalanche_labels_addr_block_num', table_name='avalanche_labels')
    op.drop_table('avalanche_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_transaction_hash'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_origin_address'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_label_type'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_label_name'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_label'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_caller_address'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_block_number'), table_name='avalanche_fuji_labels')
    op.drop_index(op.f('ix_avalanche_fuji_labels_address'), table_name='avalanche_fuji_labels')
    op.drop_index('ix_avalanche_fuji_labels_addr_block_num', table_name='avalanche_fuji_labels')
    op.drop_table('avalanche_fuji_labels')
    op.drop_index(op.f('ix_starknet_labels_transaction_hash'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_origin_address'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_label_type'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_label_name'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_label'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_caller_address'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_block_number'), table_name='starknet_labels')
    op.drop_index(op.f('ix_starknet_labels_address'), table_name='starknet_labels')
    op.drop_index('ix_starknet_labels_addr_block_num', table_name='starknet_labels')
    op.drop_table('starknet_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_transaction_hash'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_origin_address'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_label_type'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_label_name'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_label'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_caller_address'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_block_number'), table_name='starknet_sepolia_labels')
    op.drop_index(op.f('ix_starknet_sepolia_labels_address'), table_name='starknet_sepolia_labels')
    op.drop_index('ix_starknet_sepolia_labels_addr_block_num', table_name='starknet_sepolia_labels')
    op.drop_table('starknet_sepolia_labels')
    # ### end Alembic commands ###



"""Immutable zkEvm with it's sepolia blockchains

Revision ID: f19652e59bc5
Revises: a1ead76c0470
Create Date: 2024-07-25 11:34:09.513131

"""
from typing import Sequence, Union

from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision: str = 'f19652e59bc5'
down_revision: Union[str, None] = 'a1ead76c0470'
branch_labels: Union[str, Sequence[str], None] = None
depends_on: Union[str, Sequence[str], None] = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('imx_zkevm_blocks',
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('parent_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('block_number', name=op.f('pk_imx_zkevm_blocks'))
    )
    op.create_index(op.f('ix_imx_zkevm_blocks_block_number'), 'imx_zkevm_blocks', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_blocks_block_timestamp'), 'imx_zkevm_blocks', ['block_timestamp'], unique=False)
    op.create_table('imx_zkevm_reorgs',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_imx_zkevm_reorgs'))
    )
    op.create_index(op.f('ix_imx_zkevm_reorgs_block_hash'), 'imx_zkevm_reorgs', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_reorgs_block_number'), 'imx_zkevm_reorgs', ['block_number'], unique=False)
    op.create_table('imx_zkevm_sepolia_blocks',
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_timestamp', sa.BigInteger(), nullable=False),
    sa.Column('parent_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.PrimaryKeyConstraint('block_number', name=op.f('pk_imx_zkevm_sepolia_blocks'))
    )
    op.create_index(op.f('ix_imx_zkevm_sepolia_blocks_block_number'), 'imx_zkevm_sepolia_blocks', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_blocks_block_timestamp'), 'imx_zkevm_sepolia_blocks', ['block_timestamp'], unique=False)
    op.create_table('imx_zkevm_sepolia_reorgs',
    sa.Column('id', sa.UUID(), nullable=False),
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.PrimaryKeyConstraint('id', name=op.f('pk_imx_zkevm_sepolia_reorgs'))
    )
    op.create_index(op.f('ix_imx_zkevm_sepolia_reorgs_block_hash'), 'imx_zkevm_sepolia_reorgs', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_reorgs_block_number'), 'imx_zkevm_sepolia_reorgs', ['block_number'], unique=False)
    op.create_table('imx_zkevm_sepolia_transactions',
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('from_address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('to_address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('selector', sa.VARCHAR(length=256), nullable=True),
    sa.Column('type', sa.Integer(), nullable=True),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('index', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.ForeignKeyConstraint(['block_number'], ['imx_zkevm_sepolia_blocks.block_number'], name=op.f('fk_imx_zkevm_sepolia_transactions_block_number_imx_zkevm_sepolia_blocks'), ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('hash', name=op.f('pk_imx_zkevm_sepolia_transactions'))
    )
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_block_hash'), 'imx_zkevm_sepolia_transactions', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_block_number'), 'imx_zkevm_sepolia_transactions', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_from_address'), 'imx_zkevm_sepolia_transactions', ['from_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_hash'), 'imx_zkevm_sepolia_transactions', ['hash'], unique=True)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_index'), 'imx_zkevm_sepolia_transactions', ['index'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_selector'), 'imx_zkevm_sepolia_transactions', ['selector'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_to_address'), 'imx_zkevm_sepolia_transactions', ['to_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_transactions_type'), 'imx_zkevm_sepolia_transactions', ['type'], unique=False)
    op.create_table('imx_zkevm_transactions',
    sa.Column('block_number', sa.BigInteger(), nullable=False),
    sa.Column('hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('from_address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('to_address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('selector', sa.VARCHAR(length=256), nullable=True),
    sa.Column('type', sa.Integer(), nullable=True),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('index', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.ForeignKeyConstraint(['block_number'], ['imx_zkevm_blocks.block_number'], name=op.f('fk_imx_zkevm_transactions_block_number_imx_zkevm_blocks'), ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('hash', name=op.f('pk_imx_zkevm_transactions'))
    )
    op.create_index(op.f('ix_imx_zkevm_transactions_block_hash'), 'imx_zkevm_transactions', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_block_number'), 'imx_zkevm_transactions', ['block_number'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_from_address'), 'imx_zkevm_transactions', ['from_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_hash'), 'imx_zkevm_transactions', ['hash'], unique=True)
    op.create_index(op.f('ix_imx_zkevm_transactions_index'), 'imx_zkevm_transactions', ['index'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_selector'), 'imx_zkevm_transactions', ['selector'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_to_address'), 'imx_zkevm_transactions', ['to_address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_transactions_type'), 'imx_zkevm_transactions', ['type'], unique=False)
    op.create_table('imx_zkevm_logs',
    sa.Column('transaction_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('selector', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic1', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic2', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic3', sa.VARCHAR(length=256), nullable=True),
    sa.Column('log_index', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.ForeignKeyConstraint(['transaction_hash'], ['imx_zkevm_transactions.hash'], name=op.f('fk_imx_zkevm_logs_transaction_hash_imx_zkevm_transactions'), ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('transaction_hash', 'log_index', name='pk_imx_zkevm_log_index'),
    sa.UniqueConstraint('transaction_hash', 'log_index', name='uq_imx_zkevm_log_index_transaction_hash_log_index')
    )
    op.create_index('idx_imx_zkevm_logs_address_selector', 'imx_zkevm_logs', ['address', 'selector'], unique=False)
    op.create_index('idx_imx_zkevm_logs_block_hash_log_index', 'imx_zkevm_logs', ['block_hash', 'log_index'], unique=True)
    op.create_index(op.f('ix_imx_zkevm_logs_address'), 'imx_zkevm_logs', ['address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_logs_block_hash'), 'imx_zkevm_logs', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_logs_transaction_hash'), 'imx_zkevm_logs', ['transaction_hash'], unique=False)
    op.create_table('imx_zkevm_sepolia_logs',
    sa.Column('transaction_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('block_hash', sa.VARCHAR(length=256), nullable=False),
    sa.Column('address', sa.LargeBinary(length=20), nullable=False),
    sa.Column('row_id', sa.BigInteger(), nullable=False),
    sa.Column('selector', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic1', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic2', sa.VARCHAR(length=256), nullable=True),
    sa.Column('topic3', sa.VARCHAR(length=256), nullable=True),
    sa.Column('log_index', sa.BigInteger(), nullable=False),
    sa.Column('path', sa.Text(), nullable=False),
    sa.Column('indexed_at', sa.DateTime(timezone=True), server_default=sa.text("TIMEZONE('utc', statement_timestamp())"), nullable=False),
    sa.ForeignKeyConstraint(['transaction_hash'], ['imx_zkevm_sepolia_transactions.hash'], name=op.f('fk_imx_zkevm_sepolia_logs_transaction_hash_imx_zkevm_sepolia_transactions'), ondelete='CASCADE'),
    sa.PrimaryKeyConstraint('transaction_hash', 'log_index', name='pk_imx_zkevm_sepolia_log_index'),
    sa.UniqueConstraint('transaction_hash', 'log_index', name='uq_imx_zkevm_sepolia_log_index_transaction_hash_log_index')
    )
    op.create_index('idx_imx_zkevm_sepolia_logs_address_selector', 'imx_zkevm_sepolia_logs', ['address', 'selector'], unique=False)
    op.create_index('idx_imx_zkevm_sepolia_logs_block_hash_log_index', 'imx_zkevm_sepolia_logs', ['block_hash', 'log_index'], unique=True)
    op.create_index(op.f('ix_imx_zkevm_sepolia_logs_address'), 'imx_zkevm_sepolia_logs', ['address'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_logs_block_hash'), 'imx_zkevm_sepolia_logs', ['block_hash'], unique=False)
    op.create_index(op.f('ix_imx_zkevm_sepolia_logs_transaction_hash'), 'imx_zkevm_sepolia_logs', ['transaction_hash'], unique=False)
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index(op.f('ix_imx_zkevm_sepolia_logs_transaction_hash'), table_name='imx_zkevm_sepolia_logs')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_logs_block_hash'), table_name='imx_zkevm_sepolia_logs')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_logs_address'), table_name='imx_zkevm_sepolia_logs')
    op.drop_index('idx_imx_zkevm_sepolia_logs_block_hash_log_index', table_name='imx_zkevm_sepolia_logs')
    op.drop_index('idx_imx_zkevm_sepolia_logs_address_selector', table_name='imx_zkevm_sepolia_logs')
    op.drop_table('imx_zkevm_sepolia_logs')
    op.drop_index(op.f('ix_imx_zkevm_logs_transaction_hash'), table_name='imx_zkevm_logs')
    op.drop_index(op.f('ix_imx_zkevm_logs_block_hash'), table_name='imx_zkevm_logs')
    op.drop_index(op.f('ix_imx_zkevm_logs_address'), table_name='imx_zkevm_logs')
    op.drop_index('idx_imx_zkevm_logs_block_hash_log_index', table_name='imx_zkevm_logs')
    op.drop_index('idx_imx_zkevm_logs_address_selector', table_name='imx_zkevm_logs')
    op.drop_table('imx_zkevm_logs')
    op.drop_index(op.f('ix_imx_zkevm_transactions_type'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_to_address'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_selector'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_index'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_hash'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_from_address'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_block_number'), table_name='imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_transactions_block_hash'), table_name='imx_zkevm_transactions')
    op.drop_table('imx_zkevm_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_type'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_to_address'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_selector'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_index'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_hash'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_from_address'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_block_number'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_transactions_block_hash'), table_name='imx_zkevm_sepolia_transactions')
    op.drop_table('imx_zkevm_sepolia_transactions')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_reorgs_block_number'), table_name='imx_zkevm_sepolia_reorgs')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_reorgs_block_hash'), table_name='imx_zkevm_sepolia_reorgs')
    op.drop_table('imx_zkevm_sepolia_reorgs')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_blocks_block_timestamp'), table_name='imx_zkevm_sepolia_blocks')
    op.drop_index(op.f('ix_imx_zkevm_sepolia_blocks_block_number'), table_name='imx_zkevm_sepolia_blocks')
    op.drop_table('imx_zkevm_sepolia_blocks')
    op.drop_index(op.f('ix_imx_zkevm_reorgs_block_number'), table_name='imx_zkevm_reorgs')
    op.drop_index(op.f('ix_imx_zkevm_reorgs_block_hash'), table_name='imx_zkevm_reorgs')
    op.drop_table('imx_zkevm_reorgs')
    op.drop_index(op.f('ix_imx_zkevm_blocks_block_timestamp'), table_name='imx_zkevm_blocks')
    op.drop_index(op.f('ix_imx_zkevm_blocks_block_number'), table_name='imx_zkevm_blocks')
    op.drop_table('imx_zkevm_blocks')
    # ### end Alembic commands ###
